@@ -7,9 +7,9 @@ from django.contrib.auth.decorators import login_required
 import os,json
 
 from lisa.server.web.weblisa.utils import method_restricted_to, is_ajax
-# from lisa.server.web.weblisa.settings import LISA_PATH
 
-from lisa.plugins.Freebox.modules.Freebox import Freebox
+
+from lisa.plugins.Freebox.modules.freebox import Freebox
 
 # Template system will be fixed with Django 1.7. Each plugin will be able to have his own templates
 @login_required()
